@@ -186,7 +186,7 @@ class TuneTheModelFile():
         def MB(i):
             return i / 1024 ** 2
 
-        upper_limit = 1.5 * 1024 ** 2
+        upper_limit = 8 * 1024 ** 2
         if len(data) > upper_limit:
             raise TuneTheModelException(
                 f"Payload exceeds the limit {MB(upper_limit):0.1f}MB with size of {MB(len(data)):0.2f}MB"
@@ -253,10 +253,11 @@ class TuneTheModel():
     def create_classifier(cls, filename: str, train_iters: int = None, num_classes: int = None):
         model = {"model_type": "classifier"}
 
+        model["model_params"] = {}
         if train_iters:
-            model["model_params"] = {"train_iters": train_iters}
+            model["model_params"]["train_iters"] = train_iters
         if num_classes:
-            model["model_params"] = {"num_classes": num_classes}
+            model["model_params"]["num_classes"] = num_classes
 
         return cls.load_or_create(filename, model)
 
@@ -464,7 +465,7 @@ def tune_generator(
 
     .. code-block:: python
 
-        import model_one
+        import tune_the_model as ttm
 
 
         train_inputs = ["алый", "альбом"] * 32
@@ -472,7 +473,7 @@ def tune_generator(
         validation_inputs = ["бассейн", "бахрома"] * 32
         validation_outputs = ["libre", "flecos"] * 32
 
-        model = model_one.train_generator(
+        model = ttm.tune_generator(
             "classifier.json",
             train_inputs,
             train_outputs,
@@ -542,7 +543,7 @@ def tune_classifier(
 
         from datasets import load_dataset
 
-        import model_one
+        import tune_the_model as ttm
 
 
         dataset = load_dataset("tweet_eval", "irony")
@@ -550,7 +551,7 @@ def tune_classifier(
         train = pd.DataFrame(dataset["train"])
         validation = pd.DataFrame(dataset["validation"])
 
-        model = model_one.train_classifier(
+        model = ttm.tune_classifier(
             "classifier.json",
             train["text"],
             train["label"],
@@ -610,4 +611,4 @@ def generate(input: str):
         TuneTheModelException: If anything bad happens.
     """
     r = TuneTheModelAPI.vanilla_generate({"input": input})
-    return r["answer"]["responses"][0]["response"]
\ No newline at end of file
+    return r["answer"]["responses"][0]["response"]
